==> knative-model-6.8.0-sources.jar: io/fabric8/knative/serving/v1/TrafficTargetFluent.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TrafficTargetFluent<A extends TrafficTargetFluent<A>> extends BaseFluent<A>{
  public TrafficTargetFluent() {
  }
  public TrafficTargetFluent(TrafficTarget instance) {
    instance = (instance != null ? instance : new TrafficTarget());

    if (instance != null) {
      this.withConfigurationName(instance.getConfigurationName());
      this.withLatestRevision(instance.getLatestRevision());
      this.withPercent(instance.getPercent());
      this.withRevisionName(instance.getRevisionName());
      this.withTag(instance.getTag());
      this.withUrl(instance.getUrl());
      this.withConfigurationName(instance.getConfigurationName());
      this.withLatestRevision(instance.getLatestRevision());
      this.withPercent(instance.getPercent());
      this.withRevisionName(instance.getRevisionName());
      this.withTag(instance.getTag());
      this.withUrl(instance.getUrl());
    }
  }
  private String configurationName;
  private Boolean latestRevision;
  private Long percent;
  private String revisionName;
  private String tag;
  private String url;
  public String getConfigurationName() {
    return this.configurationName;
  }
  public A withConfigurationName(String configurationName) {
    this.configurationName=configurationName; return (A) this;
  }
  public boolean hasConfigurationName() {
    return this.configurationName != null;
  }
  public Boolean getLatestRevision() {
    return this.latestRevision;
  }
  public A withLatestRevision(Boolean latestRevision) {
    this.latestRevision=latestRevision; return (A) this;
  }
  public boolean hasLatestRevision() {
    return this.latestRevision != null;
  }
  public Long getPercent() {
    return this.percent;
  }
  public A withPercent(Long percent) {
    this.percent=percent; return (A) this;
  }
  public boolean hasPercent() {
    return this.percent != null;
  }
  public String getRevisionName() {
    return this.revisionName;
  }
  public A withRevisionName(String revisionName) {
    this.revisionName=revisionName; return (A) this;
  }
  public boolean hasRevisionName() {
    return this.revisionName != null;
  }
  public String getTag() {
    return this.tag;
  }
  public A withTag(String tag) {
    this.tag=tag; return (A) this;
  }
  public boolean hasTag() {
    return this.tag != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TrafficTargetFluent that = (TrafficTargetFluent) o;
    if (!java.util.Objects.equals(configurationName, that.configurationName)) return false;

    if (!java.util.Objects.equals(latestRevision, that.latestRevision)) return false;

    if (!java.util.Objects.equals(percent, that.percent)) return false;

    if (!java.util.Objects.equals(revisionName, that.revisionName)) return false;

    if (!java.util.Objects.equals(tag, that.tag)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(configurationName,  latestRevision,  percent,  revisionName,  tag,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configurationName != null) { sb.append("configurationName:"); sb.append(configurationName + ","); }
    if (latestRevision != null) { sb.append("latestRevision:"); sb.append(latestRevision + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (revisionName != null) { sb.append("revisionName:"); sb.append(revisionName + ","); }
    if (tag != null) { sb.append("tag:"); sb.append(tag + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  public A withLatestRevision() {
    return withLatestRevision(true);
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/serving/v1/TrafficTargetFluent.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class TrafficTargetFluent<A extends TrafficTargetFluent<A>> extends BaseFluent<A>{
  public TrafficTargetFluent() {
  }
  
  public TrafficTargetFluent(TrafficTarget instance) {
    this.copyInstance(instance);
  }
  private String configurationName;
  private Boolean latestRevision;
  private Long percent;
  private String revisionName;
  private String tag;
  private String url;
  
  protected void copyInstance(TrafficTarget instance) {
    instance = (instance != null ? instance : new TrafficTarget());
  
    if (instance != null) {
        this.withConfigurationName(instance.getConfigurationName());
        this.withLatestRevision(instance.getLatestRevision());
        this.withPercent(instance.getPercent());
        this.withRevisionName(instance.getRevisionName());
        this.withTag(instance.getTag());
        this.withUrl(instance.getUrl());
        this.withConfigurationName(instance.getConfigurationName());
        this.withLatestRevision(instance.getLatestRevision());
        this.withPercent(instance.getPercent());
        this.withRevisionName(instance.getRevisionName());
        this.withTag(instance.getTag());
        this.withUrl(instance.getUrl());
      }
  }
  
  public String getConfigurationName() {
    return this.configurationName;
  }
  
  public A withConfigurationName(String configurationName) {
    this.configurationName=configurationName; return (A) this;
  }
  
  public boolean hasConfigurationName() {
    return this.configurationName != null;
  }
  
  public Boolean getLatestRevision() {
    return this.latestRevision;
  }
  
  public A withLatestRevision(Boolean latestRevision) {
    this.latestRevision=latestRevision; return (A) this;
  }
  
  public boolean hasLatestRevision() {
    return this.latestRevision != null;
  }
  
  public Long getPercent() {
    return this.percent;
  }
  
  public A withPercent(Long percent) {
    this.percent=percent; return (A) this;
  }
  
  public boolean hasPercent() {
    return this.percent != null;
  }
  
  public String getRevisionName() {
    return this.revisionName;
  }
  
  public A withRevisionName(String revisionName) {
    this.revisionName=revisionName; return (A) this;
  }
  
  public boolean hasRevisionName() {
    return this.revisionName != null;
  }
  
  public String getTag() {
    return this.tag;
  }
  
  public A withTag(String tag) {
    this.tag=tag; return (A) this;
  }
  
  public boolean hasTag() {
    return this.tag != null;
  }
  
  public String getUrl() {
    return this.url;
  }
  
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  
  public boolean hasUrl() {
    return this.url != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TrafficTargetFluent that = (TrafficTargetFluent) o;
    if (!java.util.Objects.equals(configurationName, that.configurationName)) return false;
  
    if (!java.util.Objects.equals(latestRevision, that.latestRevision)) return false;
  
    if (!java.util.Objects.equals(percent, that.percent)) return false;
  
    if (!java.util.Objects.equals(revisionName, that.revisionName)) return false;
  
    if (!java.util.Objects.equals(tag, that.tag)) return false;
  
    if (!java.util.Objects.equals(url, that.url)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(configurationName,  latestRevision,  percent,  revisionName,  tag,  url,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (configurationName != null) { sb.append("configurationName:"); sb.append(configurationName + ","); }
    if (latestRevision != null) { sb.append("latestRevision:"); sb.append(latestRevision + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (revisionName != null) { sb.append("revisionName:"); sb.append(revisionName + ","); }
    if (tag != null) { sb.append("tag:"); sb.append(tag + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withLatestRevision() {
    return withLatestRevision(true);
  }
  

}
